# aiophyn

An asynchronous library for Phyn Smart Water devices including Kohler's H2Wise+.

This library is initially focused on supporting a Phyn integration for Home Assistant, providing:

- Device state
- Water consumption
- Shutoff valve control
- Get and set away mode

## Acknowledgements

This work follows the example of @bachya's excellent [aioflo](https://github.com/bachya/aioflo) library for Moen Flo devices.
